import * as React from 'react';
import './ReportTabpanel.scss';
/**
 * `ReportTabpanel` shows the `FilesTable` or `DetailsTable` depending on the active tab.
 *
 * The `FilesTable` and `DetailsTable` can be passed as children with custom props (e.g. localization, custom icons).
 *
 * @example
 * <ReportTabpanel>
 *   <FilesTable displayStrings={{ ... }} />
 *   <DetailsTable displayStrings={{ ... }} />
 * </ReportTabpanel>
 */
export declare const ReportTabpanel: ({ currentTab, children, className, ...rest }: {
    /**
     * Current tab. Will be inferred from context if not specified.
     */
    currentTab?: "details" | "files" | undefined;
    /**
     * Two `children` can be specified to override the tables.
     * @default
     * [<FilesTable />, <DetailsTable />]
     */
    children?: [React.ReactNode, React.ReactNode] | undefined;
    className?: string | undefined;
    id?: string | undefined;
}) => JSX.Element;
